# scamper python interface - cython interface to scamper_addr_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

 void scamper_addr_free(scamper_addr_t *sa)
 scamper_addr_t *scamper_addr_use(scamper_addr_t *sa)
 scamper_addr_t *scamper_addr_fromstr(int kind, const char *addr)
 scamper_addr_t *scamper_addr_alloc(int kind, const void *addr)

 const char *scamper_addr_tostr(const scamper_addr_t *sa,
			        char *dst, const size_t size)
 int scamper_addr_cmp(const scamper_addr_t *a, const scamper_addr_t *b)
 int scamper_addr_human_cmp(const scamper_addr_t *a, const scamper_addr_t *b)

 bint scamper_addr_islinklocal(const scamper_addr_t *a)
 bint scamper_addr_isrfc1918(const scamper_addr_t *a)
 bint scamper_addr_isunicast(const scamper_addr_t *a)
 bint scamper_addr_is6to4(const scamper_addr_t *a)
 bint scamper_addr_isreserved(const scamper_addr_t *a)
 bint scamper_addr_isipv4(const scamper_addr_t *a)
 bint scamper_addr_isipv6(const scamper_addr_t *a)
 bint scamper_addr_isethernet(const scamper_addr_t *a)
 bint scamper_addr_isfirewire(const scamper_addr_t *a)

 const void *scamper_addr_addr_get(const scamper_addr_t *addr)
 int scamper_addr_type_get(const scamper_addr_t *addr)
 size_t scamper_addr_len_get(const scamper_addr_t *addr)



# scamper python interface - cython interface to scamper_tracelb_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2024 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_icmpext.h":
 ctypedef struct scamper_icmpext_t:
  pass
 ctypedef struct scamper_icmpexts_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_tracelb.h":
 ctypedef struct scamper_tracelb_t:
  pass
 ctypedef struct scamper_tracelb_node_t:
  pass
 ctypedef struct scamper_tracelb_link_t:
  pass
 ctypedef struct scamper_tracelb_probe_t:
  pass
 ctypedef struct scamper_tracelb_reply_t:
  pass
 ctypedef struct scamper_tracelb_probeset_t:
  pass
 ctypedef struct scamper_tracelb_probeset_summary_t:
  pass

 char *scamper_tracelb_tojson(const scamper_tracelb_t *tracelb, size_t *l)
 char *scamper_tracelb_totext(const scamper_tracelb_t *tracelb, size_t *l)

 void scamper_tracelb_free(scamper_tracelb_t *tracelb)
 char *scamper_tracelb_type_tostr(const scamper_tracelb_t *trace, char *buf, size_t len)
 scamper_list_t *scamper_tracelb_list_get(const scamper_tracelb_t *trace)
 scamper_cycle_t *scamper_tracelb_cycle_get(const scamper_tracelb_t *trace)
 uint32_t scamper_tracelb_userid_get(const scamper_tracelb_t *trace)
 scamper_addr_t *scamper_tracelb_src_get(const scamper_tracelb_t *trace)
 scamper_addr_t *scamper_tracelb_dst_get(const scamper_tracelb_t *trace)
 scamper_addr_t *scamper_tracelb_rtr_get(const scamper_tracelb_t *trace)
 const timeval *scamper_tracelb_start_get(const scamper_tracelb_t *trace)
 uint16_t scamper_tracelb_sport_get(const scamper_tracelb_t *trace)
 uint16_t scamper_tracelb_dport_get(const scamper_tracelb_t *trace)
 uint16_t scamper_tracelb_probe_size_get(const scamper_tracelb_t *trace)
 uint8_t scamper_tracelb_type_get(const scamper_tracelb_t *trace)
 uint8_t scamper_tracelb_firsthop_get(const scamper_tracelb_t *trace)
 const timeval *scamper_tracelb_wait_timeout_get(const scamper_tracelb_t *trace)
 const timeval *scamper_tracelb_wait_probe_get(const scamper_tracelb_t *trace)
 uint8_t scamper_tracelb_attempts_get(const scamper_tracelb_t *trace)
 uint8_t scamper_tracelb_confidence_get(const scamper_tracelb_t *trace)
 uint8_t scamper_tracelb_tos_get(const scamper_tracelb_t *trace)
 uint8_t scamper_tracelb_gaplimit_get(const scamper_tracelb_t *trace)
 uint32_t scamper_tracelb_flags_get(const scamper_tracelb_t *trace)
 uint32_t scamper_tracelb_probec_max_get(const scamper_tracelb_t *trace)
 uint16_t scamper_tracelb_nodec_get(const scamper_tracelb_t *trace)
 scamper_tracelb_node_t *scamper_tracelb_node_get(const scamper_tracelb_t *trace, uint16_t i)
 uint16_t scamper_tracelb_linkc_get(const scamper_tracelb_t *trace)
 scamper_tracelb_link_t *scamper_tracelb_link_get(const scamper_tracelb_t *trace, uint16_t i)
 uint32_t scamper_tracelb_probec_get(const scamper_tracelb_t *trace)
 uint32_t scamper_tracelb_error_get(const scamper_tracelb_t *trace)
 bint scamper_tracelb_type_is_udp(const scamper_tracelb_t *trace)
 bint scamper_tracelb_type_is_tcp(const scamper_tracelb_t *trace)
 bint scamper_tracelb_type_is_icmp(const scamper_tracelb_t *trace)
 bint scamper_tracelb_type_is_vary_sport(const scamper_tracelb_t *trace)

 scamper_tracelb_node_t *scamper_tracelb_node_use(scamper_tracelb_node_t *node)
 void scamper_tracelb_node_free(scamper_tracelb_node_t *node)
 scamper_addr_t *scamper_tracelb_node_addr_get(const scamper_tracelb_node_t *node)
 const char *scamper_tracelb_node_name_get(const scamper_tracelb_node_t *node)
 uint32_t scamper_tracelb_node_flags_get(const scamper_tracelb_node_t *node)
 uint8_t scamper_tracelb_node_q_ttl_get(const scamper_tracelb_node_t *node)
 scamper_tracelb_link_t *scamper_tracelb_node_link_get(const scamper_tracelb_node_t *node, uint16_t i)
 uint16_t scamper_tracelb_node_linkc_get(const scamper_tracelb_node_t *node)
 bint scamper_tracelb_node_is_q_ttl(const scamper_tracelb_node_t *node)

 scamper_tracelb_link_t *scamper_tracelb_link_use(scamper_tracelb_link_t *link)
 void scamper_tracelb_link_free(scamper_tracelb_link_t *link)
 scamper_tracelb_node_t *scamper_tracelb_link_from_get(const scamper_tracelb_link_t *link)
 scamper_tracelb_node_t *scamper_tracelb_link_to_get(const scamper_tracelb_link_t *link)
 uint8_t scamper_tracelb_link_hopc_get(const scamper_tracelb_link_t *link)
 scamper_tracelb_probeset_t *scamper_tracelb_link_probeset_get(const scamper_tracelb_link_t *link, uint8_t hop)

 scamper_tracelb_probeset_t *scamper_tracelb_probeset_use(scamper_tracelb_probeset_t *pset)
 void scamper_tracelb_probeset_free(scamper_tracelb_probeset_t *pset)

 scamper_tracelb_probe_t *scamper_tracelb_probeset_probe_get(const scamper_tracelb_probeset_t *pset, uint16_t i)
 uint16_t scamper_tracelb_probeset_probec_get(const scamper_tracelb_probeset_t *pset)

 scamper_tracelb_probe_t *scamper_tracelb_probe_use(scamper_tracelb_probe_t *probe)
 void scamper_tracelb_probe_free(scamper_tracelb_probe_t *probe)
 const timeval *scamper_tracelb_probe_tx_get(const scamper_tracelb_probe_t *probe)
 uint16_t scamper_tracelb_probe_flowid_get(const scamper_tracelb_probe_t *probe)
 uint8_t scamper_tracelb_probe_ttl_get(const scamper_tracelb_probe_t *probe)
 uint8_t scamper_tracelb_probe_attempt_get(const scamper_tracelb_probe_t *probe)
 scamper_tracelb_reply_t *scamper_tracelb_probe_rx_get(const scamper_tracelb_probe_t *probe, uint16_t i)
 uint16_t scamper_tracelb_probe_rxc_get(const scamper_tracelb_probe_t *probe)

 scamper_tracelb_reply_t *scamper_tracelb_reply_use(scamper_tracelb_reply_t *reply)
 void scamper_tracelb_reply_free(scamper_tracelb_reply_t *reply)
 scamper_addr_t *scamper_tracelb_reply_from_get(const scamper_tracelb_reply_t *reply)
 const timeval *scamper_tracelb_reply_rx_get(const scamper_tracelb_reply_t *reply)
 uint16_t scamper_tracelb_reply_ipid_get(const scamper_tracelb_reply_t *reply)
 uint8_t scamper_tracelb_reply_ttl_get(const scamper_tracelb_reply_t *reply)
 uint32_t scamper_tracelb_reply_flags_get(const scamper_tracelb_reply_t *reply)
 uint8_t scamper_tracelb_reply_icmp_type_get(const scamper_tracelb_reply_t *reply)
 uint8_t scamper_tracelb_reply_icmp_code_get(const scamper_tracelb_reply_t *reply)
 uint8_t scamper_tracelb_reply_icmp_q_tos_get(const scamper_tracelb_reply_t *reply)
 uint8_t scamper_tracelb_reply_icmp_q_ttl_get(const scamper_tracelb_reply_t *reply)
 uint8_t scamper_tracelb_reply_tcp_flags_get(const scamper_tracelb_reply_t *reply)
 bint scamper_tracelb_reply_is_icmp(const scamper_tracelb_reply_t *reply)
 bint scamper_tracelb_reply_is_icmp_q(const scamper_tracelb_reply_t *reply)
 bint scamper_tracelb_reply_is_icmp_ttl_exp(const scamper_tracelb_reply_t *reply)
 bint scamper_tracelb_reply_is_icmp_unreach(const scamper_tracelb_reply_t *reply)
 bint scamper_tracelb_reply_is_tcp(const scamper_tracelb_reply_t *reply)
 bint scamper_tracelb_reply_is_reply_ttl(const scamper_tracelb_reply_t *reply)
 scamper_icmpexts_t *scamper_tracelb_reply_icmp_exts_get(const scamper_tracelb_reply_t *reply)

 scamper_tracelb_probeset_summary_t *scamper_tracelb_probeset_summary_alloc(const scamper_tracelb_probeset_t *set)
 void scamper_tracelb_probeset_summary_free(scamper_tracelb_probeset_summary_t *sum)
 uint16_t scamper_tracelb_probeset_summary_addrc_get(const scamper_tracelb_probeset_summary_t *sum)
 scamper_addr_t *scamper_tracelb_probeset_summary_addr_get(const scamper_tracelb_probeset_summary_t *sum, uint16_t i)
 uint16_t scamper_tracelb_probeset_summary_nullc_get(const scamper_tracelb_probeset_summary_t *sum)



# scamper python interface: cython interface to libscamperctrl
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2025 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "libscamperctrl.h":
 ctypedef struct scamper_ctrl_t:
  pass

 ctypedef struct scamper_inst_t:
  pass

 ctypedef struct scamper_attp_t:
  pass

 ctypedef struct scamper_task_t:
  pass

 ctypedef struct scamper_mux_t:
  pass

 ctypedef struct scamper_vpset_t:
  pass

 ctypedef struct scamper_vp_t:
  pass

 ctypedef void (*scamper_ctrl_cb_t)(scamper_inst_t *inst, uint8_t type,
				    scamper_task_t *task,
				    const void *data, size_t len)

 scamper_ctrl_t *scamper_ctrl_alloc(scamper_ctrl_cb_t cb)
 int scamper_ctrl_wait(scamper_ctrl_t *ctrl, timeval *to)
 void scamper_ctrl_free(scamper_ctrl_t *ctrl)
 bint scamper_ctrl_isdone(scamper_ctrl_t *ctrl)
 void *scamper_ctrl_param_get(const scamper_ctrl_t *ctrl)
 void scamper_ctrl_param_set(scamper_ctrl_t *ctrl, void *param)
 const char *scamper_ctrl_strerror(const scamper_ctrl_t *ctrl)

 scamper_inst_t *scamper_inst_vp(scamper_ctrl_t *ctrl, const scamper_vp_t *vp)
 scamper_inst_t *scamper_inst_unix(scamper_ctrl_t *ctrl,
				   const scamper_attp_t *attp,
				   const char *path)
 scamper_inst_t *scamper_inst_inet(scamper_ctrl_t *ctrl,
				   const scamper_attp_t *attp,
				   const char *addr, uint16_t port)
 scamper_inst_t *scamper_inst_remote(scamper_ctrl_t *ctrl, const char *path)

 void scamper_inst_free(scamper_inst_t *inst)
 scamper_task_t *scamper_inst_do(scamper_inst_t *inst, const char *cmd, void *p)
 int scamper_inst_done(scamper_inst_t *inst)
 void *scamper_inst_param_get(const scamper_inst_t *inst)
 void scamper_inst_param_set(scamper_inst_t *inst, void *param)
 scamper_ctrl_t *scamper_inst_ctrl_get(const scamper_inst_t *inst)
 const char *scamper_inst_name_get(const scamper_inst_t *inst)
 scamper_vp_t *scamper_inst_vp_get(const scamper_inst_t *inst)

 bint scamper_inst_is_muxvp(const scamper_inst_t *inst)
 bint scamper_inst_is_inet(const scamper_inst_t *inst)
 bint scamper_inst_is_unix(const scamper_inst_t *inst)
 bint scamper_inst_is_remote(const scamper_inst_t *inst)

 int scamper_task_halt(scamper_task_t *task)
 void *scamper_task_param_get(const scamper_task_t *task)
 void scamper_task_param_set(scamper_task_t *task, void *param)
 void scamper_task_free(scamper_task_t *task)
 scamper_task_t *scamper_task_use(scamper_task_t *task)

 scamper_mux_t *scamper_mux_add(scamper_ctrl_t *ctrl, const char *path)

 scamper_vpset_t *scamper_vpset_get(const scamper_mux_t *mux)
 void scamper_vpset_free(scamper_vpset_t *vps)
 size_t scamper_vpset_vp_count(const scamper_vpset_t *vps)
 scamper_vp_t *scamper_vpset_vp_get(const scamper_vpset_t *vps, size_t i)

 void scamper_vp_free(scamper_vp_t *vp)
 scamper_vp_t *scamper_vp_use(scamper_vp_t *vp)
 const char *scamper_vp_name_get(const scamper_vp_t *vp)
 const char *scamper_vp_shortname_get(const scamper_vp_t *vp)
 const char *scamper_vp_ipv4_get(const scamper_vp_t *vp)
 const char *scamper_vp_asn4_get(const scamper_vp_t *vp)
 const char *scamper_vp_cc_get(const scamper_vp_t *vp)
 const char *scamper_vp_st_get(const scamper_vp_t *vp)
 const char *scamper_vp_place_get(const scamper_vp_t *vp)
 const char *scamper_vp_latlong_get(const scamper_vp_t *vp)
 size_t scamper_vp_tagc_get(const scamper_vp_t *vp)
 const char *scamper_vp_tag_get(const scamper_vp_t *vp, size_t i)

 scamper_attp_t *scamper_attp_alloc()
 void scamper_attp_listid_set(scamper_attp_t *attp, uint32_t list_id)
 int scamper_attp_listname_set(scamper_attp_t *attp, char *list_name)
 int scamper_attp_listdescr_set(scamper_attp_t *attp, char *list_descr)
 int scamper_attp_listmonitor_set(scamper_attp_t *attp, char *list_monitor)
 void scamper_attp_cycleid_set(scamper_attp_t *attp, uint32_t cycle_id)
 void scamper_attp_priority_set(scamper_attp_t *attp, uint32_t priority)
 void scamper_attp_free(scamper_attp_t *attp)



# scamper python interface - cython interface to scamper_list_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint32_t
from posix.time cimport time_t

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

 scamper_list_t *scamper_list_use(scamper_list_t *list)
 void scamper_list_free(scamper_list_t *list)
 uint32_t scamper_list_id_get(const scamper_list_t *list)
 const char *scamper_list_name_get(const scamper_list_t *list)
 const char *scamper_list_descr_get(const scamper_list_t *list)
 const char *scamper_list_monitor_get(const scamper_list_t *list)
 int scamper_list_cmp(const scamper_list_t *a, const scamper_list_t *b)

 scamper_cycle_t *scamper_cycle_use(scamper_cycle_t *cycle)
 void scamper_cycle_free(scamper_cycle_t *cycle)
 scamper_list_t *scamper_cycle_list_get(const scamper_cycle_t *cycle)
 uint32_t scamper_cycle_id_get(const scamper_cycle_t *cycle)
 time_t scamper_cycle_start_time_get(const scamper_cycle_t *cycle)
 time_t scamper_cycle_stop_time_get(const scamper_cycle_t *cycle)
 const char *scamper_cycle_hostname_get(const scamper_cycle_t *cycle)
 int scamper_cycle_cmp(scamper_cycle_t *a, scamper_cycle_t *b)



# scamper python interface - cython interface to scamper_ping_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2025 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_ping.h":
 ctypedef struct scamper_ping_t:
  pass
 ctypedef struct scamper_ping_v4ts_t:
  pass
 ctypedef struct scamper_ping_probe_t:
  pass
 ctypedef struct scamper_ping_reply_t:
  pass
 ctypedef struct scamper_ping_reply_v4rr_t:
  pass
 ctypedef struct scamper_ping_reply_v4ts_t:
  pass
 ctypedef struct scamper_ping_reply_tsreply_t:
  pass
 ctypedef struct scamper_ping_stats_t:
  pass

 char *scamper_ping_tojson(const scamper_ping_t *ping, size_t *l)
 char *scamper_ping_totext(const scamper_ping_t *ping, size_t *l)

 void scamper_ping_free(scamper_ping_t *ping)

 scamper_list_t *scamper_ping_list_get(const scamper_ping_t *ping)
 scamper_cycle_t *scamper_ping_cycle_get(const scamper_ping_t *ping)
 uint32_t scamper_ping_userid_get(const scamper_ping_t *ping)
 scamper_addr_t *scamper_ping_dst_get(const scamper_ping_t *ping)
 scamper_addr_t *scamper_ping_src_get(const scamper_ping_t *ping)
 scamper_addr_t *scamper_ping_rtr_get(const scamper_ping_t *ping)
 const timeval *scamper_ping_start_get(const scamper_ping_t *ping)
 uint8_t scamper_ping_stop_reason_get(const scamper_ping_t *ping)
 uint8_t scamper_ping_stop_data_get(const scamper_ping_t *ping)
 const uint8_t *scamper_ping_data_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_datalen_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_attempts_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_pktsize_get(const scamper_ping_t *ping)
 uint8_t scamper_ping_method_get(const scamper_ping_t *ping)
 char *scamper_ping_method_tostr(const scamper_ping_t *, char *, size_t)
 bint scamper_ping_method_is_icmp(const scamper_ping_t *ping)
 bint scamper_ping_method_is_icmp_time(const scamper_ping_t *ping)
 bint scamper_ping_method_is_tcp(const scamper_ping_t *ping)
 bint scamper_ping_method_is_tcp_ack_sport(const scamper_ping_t *ping)
 bint scamper_ping_method_is_udp(const scamper_ping_t *ping)
 bint scamper_ping_method_is_vary_sport(const scamper_ping_t *ping)
 bint scamper_ping_method_is_vary_dport(const scamper_ping_t *ping)
 const timeval *scamper_ping_wait_probe_get(const scamper_ping_t *ping)
 const timeval *scamper_ping_wait_timeout_get(const scamper_ping_t *ping)
 uint8_t scamper_ping_ttl_get(const scamper_ping_t *ping)
 uint8_t scamper_ping_tos_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_sport_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_dport_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_icmpsum_get(const scamper_ping_t *ping)
 uint32_t scamper_ping_tcpseq_get(const scamper_ping_t *ping)
 uint32_t scamper_ping_tcpack_get(const scamper_ping_t *ping)
 scamper_ping_v4ts_t *scamper_ping_tsps_get(const scamper_ping_t *ping)
 uint32_t scamper_ping_flags_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_stop_count_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_pmtu_get(const scamper_ping_t *ping)
 uint16_t scamper_ping_sent_get(const scamper_ping_t *ping)
 scamper_ping_probe_t *scamper_ping_probe_get(const scamper_ping_t *ping, uint16_t i)

 void scamper_ping_probe_free(scamper_ping_probe_t *probe)
 scamper_ping_probe_t *scamper_ping_probe_use(scamper_ping_probe_t *probe)
 uint16_t scamper_ping_probe_id_get(const scamper_ping_probe_t *probe)
 uint16_t scamper_ping_probe_ipid_get(const scamper_ping_probe_t *probe)
 uint32_t scamper_ping_probe_flags_get(const scamper_ping_probe_t *probe)
 const timeval *scamper_ping_probe_tx_get(const scamper_ping_probe_t *probe)
 scamper_ping_reply_t *scamper_ping_probe_reply_get(const scamper_ping_probe_t *probe, uint16_t i)

 void scamper_ping_reply_free(scamper_ping_reply_t *reply)
 scamper_ping_reply_t *scamper_ping_reply_use(scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_from_target(const scamper_ping_t *ping, const scamper_ping_reply_t *reply)
 scamper_addr_t *scamper_ping_reply_addr_get(const scamper_ping_reply_t *reply)
 uint8_t scamper_ping_reply_proto_get(const scamper_ping_reply_t *reply)
 uint8_t scamper_ping_reply_ttl_get(const scamper_ping_reply_t *reply)
 uint16_t scamper_ping_reply_size_get(const scamper_ping_reply_t *reply)
 uint16_t scamper_ping_reply_ipid_get(const scamper_ping_reply_t *reply)
 uint32_t scamper_ping_reply_ipid32_get(const scamper_ping_reply_t *reply)
 uint32_t scamper_ping_reply_flags_get(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_flag_is_reply_ipid(const scamper_ping_reply_t *reply)
 uint8_t scamper_ping_reply_icmp_type_get(const scamper_ping_reply_t *reply)
 uint8_t scamper_ping_reply_icmp_code_get(const scamper_ping_reply_t *reply)
 uint16_t scamper_ping_reply_icmp_nhmtu_get(const scamper_ping_reply_t *reply)
 uint8_t scamper_ping_reply_tcp_flags_get(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_icmp(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_tcp(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_udp(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_icmp_echo_reply(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_icmp_unreach(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_icmp_unreach_port(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_icmp_ttl_exp(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_icmp_tsreply(const scamper_ping_reply_t *reply)
 bint scamper_ping_reply_is_icmp_ptb(const scamper_ping_reply_t *reply)
 const timeval *scamper_ping_reply_rtt_get(const scamper_ping_reply_t *reply)
 scamper_ping_reply_v4rr_t *scamper_ping_reply_v4rr_get(const scamper_ping_reply_t *reply)
 scamper_ping_reply_v4ts_t *scamper_ping_reply_v4ts_get(const scamper_ping_reply_t *reply)
 scamper_ping_reply_tsreply_t *scamper_ping_reply_tsreply_get(const scamper_ping_reply_t *reply)
 const char *scamper_ping_reply_ifname_get(const scamper_ping_reply_t *reply)

 void scamper_ping_reply_tsreply_free(scamper_ping_reply_tsreply_t *tsr)
 uint32_t scamper_ping_reply_tsreply_tso_get(const scamper_ping_reply_tsreply_t *tsr)
 uint32_t scamper_ping_reply_tsreply_tsr_get(const scamper_ping_reply_tsreply_t *tsr)
 uint32_t scamper_ping_reply_tsreply_tst_get(const scamper_ping_reply_tsreply_t *tsr)

 void scamper_ping_reply_v4rr_free(scamper_ping_reply_v4rr_t *rr)
 uint8_t scamper_ping_reply_v4rr_ipc_get(const scamper_ping_reply_v4rr_t *rr)
 scamper_addr_t *scamper_ping_reply_v4rr_ip_get(const scamper_ping_reply_v4rr_t *rr, uint8_t i)

 void scamper_ping_reply_v4ts_free(scamper_ping_reply_v4ts_t *ts)
 uint8_t scamper_ping_reply_v4ts_tsc_get(const scamper_ping_reply_v4ts_t *ts)
 uint32_t scamper_ping_reply_v4ts_ts_get(const scamper_ping_reply_v4ts_t *ts, uint8_t i)
 bint scamper_ping_reply_v4ts_hasip(const scamper_ping_reply_v4ts_t *ts)
 scamper_addr_t *scamper_ping_reply_v4ts_ip_get(const scamper_ping_reply_v4ts_t *ts, uint8_t i)

 void scamper_ping_v4ts_free(scamper_ping_v4ts_t *ts)
 uint8_t scamper_ping_v4ts_ipc_get(const scamper_ping_v4ts_t *ts)
 scamper_addr_t *scamper_ping_v4ts_ip_get(const scamper_ping_v4ts_t *ts, uint8_t i)

 scamper_ping_stats_t *scamper_ping_stats_alloc(const scamper_ping_t *ping)
 void scamper_ping_stats_free(scamper_ping_stats_t *stats)
 uint32_t scamper_ping_stats_nreplies_get(const scamper_ping_stats_t *stats)
 uint32_t scamper_ping_stats_ndups_get(const scamper_ping_stats_t *stats)
 uint32_t scamper_ping_stats_nloss_get(const scamper_ping_stats_t *stats)
 uint32_t scamper_ping_stats_nerrs_get(const scamper_ping_stats_t *stats)
 const timeval *scamper_ping_stats_min_rtt_get(const scamper_ping_stats_t *stats)
 const timeval *scamper_ping_stats_max_rtt_get(const scamper_ping_stats_t *stats)
 const timeval *scamper_ping_stats_avg_rtt_get(const scamper_ping_stats_t *stats)
 const timeval *scamper_ping_stats_stddev_rtt_get(const scamper_ping_stats_t *stats)



# scamper python interface - cython interface to scamper_file_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t

cdef extern from "scamper_file.h":
 ctypedef struct scamper_file_t:
  pass

 ctypedef struct scamper_file_filter_t:
  pass

 ctypedef struct scamper_file_readbuf_t:
  pass

 ctypedef int (*scamper_file_readfunc_t)(void *param,
				         uint8_t **data, size_t len)

 scamper_file_t *scamper_file_open(const char *filename,
                                   char mode, const char *type)
 scamper_file_t *scamper_file_opennull(char mode, const char *type)
 char *scamper_file_type_tostr(scamper_file_t *sf, char *buf, size_t len)
 void scamper_file_close(scamper_file_t *sf)
 char *scamper_file_getfilename(scamper_file_t *sf)
 int scamper_file_read(scamper_file_t *sf, const scamper_file_filter_t *filter,
                       uint16_t *obj_type, void **obj_data)
 void scamper_file_setreadfunc(scamper_file_t *sf, void *param,
			       scamper_file_readfunc_t readfunc)

 scamper_file_filter_t *scamper_file_filter_alloc(const uint16_t *types,
						  uint16_t num)
 void scamper_file_filter_free(scamper_file_filter_t *filter)

 scamper_file_readbuf_t *scamper_file_readbuf_alloc()
 int scamper_file_readbuf_add(scamper_file_readbuf_t *rb,
			      const void *data, size_t len)
 void scamper_file_readbuf_free(scamper_file_readbuf_t *rb)
 int scamper_file_readbuf_read(void *param, uint8_t **data, size_t len)

 int scamper_file_write_obj(scamper_file_t *sf,
			    uint16_t o_type, void *o_data)



# scamper python interface - cython interface to scamper_neighbourdisc_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2025 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

cdef extern from "scamper_neighbourdisc.h":
 ctypedef struct scamper_neighbourdisc_t:
  pass

 char *scamper_neighbourdisc_tojson(const scamper_neighbourdisc_t *nd, size_t *l)

 void scamper_neighbourdisc_free(scamper_neighbourdisc_t *nd)



# scamper python interface - cython interface to scamper_trace_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2025 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_icmpext.h":
 ctypedef struct scamper_icmpext_t:
  pass
 ctypedef struct scamper_icmpexts_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_trace.h":
 ctypedef struct scamper_trace_t:
  pass

 ctypedef struct scamper_trace_probe_t:
  pass

 ctypedef struct scamper_trace_reply_t:
  pass

 ctypedef struct scamper_trace_hopiter_t:
  pass

 ctypedef struct scamper_trace_pmtud_t:
  pass

 ctypedef struct scamper_trace_pmtud_note_t:
  pass

 ctypedef struct scamper_trace_pmtud_noteiter_t:
  pass

 char *scamper_trace_tojson(const scamper_trace_t *trace, size_t *l)
 char *scamper_trace_totext(const scamper_trace_t *trace, size_t *l)

 void scamper_trace_free(scamper_trace_t *trace)

 scamper_list_t *scamper_trace_list_get(const scamper_trace_t *trace)
 scamper_cycle_t *scamper_trace_cycle_get(const scamper_trace_t *trace)
 scamper_addr_t *scamper_trace_src_get(const scamper_trace_t *trace)
 scamper_addr_t *scamper_trace_dst_get(const scamper_trace_t *trace)
 scamper_addr_t *scamper_trace_rtr_get(const scamper_trace_t *trace)
 uint32_t scamper_trace_userid_get(const scamper_trace_t *trace)
 const timeval *scamper_trace_start_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_stop_reason_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_stop_data_get(const scamper_trace_t *trace)
 char *scamper_trace_stop_tostr(const scamper_trace_t *trace,
                                char *buf, size_t len)
 uint16_t scamper_trace_hop_count_get(const scamper_trace_t *trace)
 uint8_t  scamper_trace_stop_hop_get(const scamper_trace_t *trace)

 uint8_t scamper_trace_type_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_attempts_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_hoplimit_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_squeries_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_gaplimit_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_gapaction_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_firsthop_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_tos_get(const scamper_trace_t *trace)
 const timeval *scamper_trace_wait_timeout_get(const scamper_trace_t *trace)
 const timeval *scamper_trace_wait_probe_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_loops_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_loopaction_get(const scamper_trace_t *trace)
 uint8_t scamper_trace_confidence_get(const scamper_trace_t *trace)
 uint16_t scamper_trace_size_get(const scamper_trace_t *trace)
 uint16_t scamper_trace_sport_get(const scamper_trace_t *trace)
 uint16_t scamper_trace_dport_get(const scamper_trace_t *trace)
 uint16_t scamper_trace_offset_get(const scamper_trace_t *trace)
 uint32_t scamper_trace_flags_get(const scamper_trace_t *trace)
 uint16_t scamper_trace_payload_len_get(const scamper_trace_t *trace)
 const uint8_t *scamper_trace_payload_get(const scamper_trace_t *trace)
 uint16_t scamper_trace_probec_get(const scamper_trace_t *trace)
 bint scamper_trace_type_is_udp(const scamper_trace_t *trace)
 bint scamper_trace_type_is_tcp(const scamper_trace_t *trace)
 bint scamper_trace_type_is_icmp(const scamper_trace_t *trace)
 bint scamper_trace_flag_is_icmpcsumdp(const scamper_trace_t *trace)

 scamper_trace_hopiter_t *scamper_trace_hopiter_alloc()
 void scamper_trace_hopiter_free(scamper_trace_hopiter_t *hi)
 void scamper_trace_hopiter_reset(scamper_trace_hopiter_t *hi)
 int scamper_trace_hopiter_ttl_set(scamper_trace_hopiter_t *hi, uint8_t ttl, uint8_t max)
 scamper_trace_probe_t *scamper_trace_hopiter_probe_get(const scamper_trace_hopiter_t *hi)
 scamper_trace_reply_t *scamper_trace_hopiter_next(const scamper_trace_t *trace, scamper_trace_hopiter_t *hi)

 scamper_trace_probe_t *scamper_trace_probe_use(scamper_trace_probe_t *probe)
 void scamper_trace_probe_free(scamper_trace_probe_t *probe)
 uint8_t scamper_trace_probe_id_get(const scamper_trace_probe_t *probe)
 uint8_t scamper_trace_probe_ttl_get(const scamper_trace_probe_t *probe)
 uint16_t scamper_trace_probe_size_get(const scamper_trace_probe_t *probe)
 const timeval *scamper_trace_probe_tx_get(const scamper_trace_probe_t *probe)

 scamper_trace_reply_t *scamper_trace_reply_use(scamper_trace_reply_t *reply)
 void scamper_trace_reply_free(scamper_trace_reply_t *reply)
 scamper_addr_t *scamper_trace_reply_addr_get(const scamper_trace_reply_t *reply)
 const char *scamper_trace_reply_name_get(const scamper_trace_reply_t *reply)
 uint32_t scamper_trace_reply_flags_get(const scamper_trace_reply_t *reply)
 const timeval *scamper_trace_reply_rtt_get(const scamper_trace_reply_t *reply)

 uint8_t scamper_trace_reply_ttl_get(const scamper_trace_reply_t *reply)
 uint8_t scamper_trace_reply_tos_get(const scamper_trace_reply_t *reply)
 uint16_t scamper_trace_reply_size_get(const scamper_trace_reply_t *reply)
 uint16_t scamper_trace_reply_ipid_get(const scamper_trace_reply_t *reply)
 uint8_t scamper_trace_reply_icmp_type_get(const scamper_trace_reply_t *reply)
 uint8_t scamper_trace_reply_icmp_code_get(const scamper_trace_reply_t *reply)
 bint scamper_trace_reply_is_tcp(const scamper_trace_reply_t *reply)
 bint scamper_trace_reply_is_icmp(const scamper_trace_reply_t *reply)
 bint scamper_trace_reply_is_icmp_q(const scamper_trace_reply_t *reply)
 bint scamper_trace_reply_is_icmp_unreach_port(const scamper_trace_reply_t *reply)
 bint scamper_trace_reply_is_icmp_echo_reply(const scamper_trace_reply_t *reply)
 bint scamper_trace_reply_is_icmp_ttl_exp(const scamper_trace_reply_t *reply)
 bint scamper_trace_reply_is_icmp_ptb(const scamper_trace_reply_t *reply)
 uint16_t scamper_trace_reply_icmp_nhmtu_get(const scamper_trace_reply_t *reply)
 uint8_t scamper_trace_reply_icmp_q_ttl_get(const scamper_trace_reply_t *reply)
 uint8_t scamper_trace_reply_icmp_q_tos_get(const scamper_trace_reply_t *reply)
 uint16_t scamper_trace_reply_icmp_q_ipl_get(const scamper_trace_reply_t *reply)
 uint8_t scamper_trace_reply_tcp_flags_get(const scamper_trace_reply_t *reply)
 scamper_icmpexts_t *scamper_trace_reply_icmp_exts_get(const scamper_trace_reply_t *reply)

 scamper_trace_pmtud_t *scamper_trace_pmtud_get(const scamper_trace_t *trace)
 void scamper_trace_pmtud_free(scamper_trace_pmtud_t *pmtud)
 scamper_trace_pmtud_t *scamper_trace_pmtud_use(scamper_trace_pmtud_t *pmtud)
 uint8_t scamper_trace_pmtud_ver_get(const scamper_trace_pmtud_t *pmtud)
 uint16_t scamper_trace_pmtud_pmtu_get(const scamper_trace_pmtud_t *pmtud)
 uint16_t scamper_trace_pmtud_ifmtu_get(const scamper_trace_pmtud_t *pmtud)
 uint16_t scamper_trace_pmtud_outmtu_get(const scamper_trace_pmtud_t *pmtud)

 scamper_trace_pmtud_note_t *scamper_trace_pmtud_note_use(scamper_trace_pmtud_note_t *n)
 void scamper_trace_pmtud_note_free(scamper_trace_pmtud_note_t *n)
 scamper_trace_probe_t *scamper_trace_pmtud_note_probe_get(const scamper_trace_pmtud_note_t *n)
 scamper_trace_reply_t *scamper_trace_pmtud_note_reply_get(const scamper_trace_pmtud_note_t *n)
 uint16_t scamper_trace_pmtud_note_nhmtu_get(const scamper_trace_pmtud_note_t *n)
 uint8_t scamper_trace_pmtud_note_type_get(const scamper_trace_pmtud_note_t *n)
 char *scamper_trace_pmtud_note_type_tostr(const scamper_trace_pmtud_note_t *n, char *buf, size_t len)

 scamper_trace_pmtud_noteiter_t *scamper_trace_pmtud_noteiter_alloc()
 void scamper_trace_pmtud_noteiter_free(scamper_trace_pmtud_noteiter_t *ni)
 scamper_trace_pmtud_note_t *scamper_trace_pmtud_noteiter_next(const scamper_trace_t *trace, scamper_trace_pmtud_noteiter_t *ni)
 uint8_t scamper_trace_pmtud_noteiter_dist_get(const scamper_trace_t *trace, scamper_trace_pmtud_noteiter_t *ni)



# scamper python interface - cython interface to scamper_http_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_http.h":
 ctypedef struct scamper_http_t:
  pass

 ctypedef struct scamper_http_buf_t:
  pass

 ctypedef struct scamper_http_hdr_field_t:
  pass

 ctypedef struct scamper_http_hdr_fields_t:
  pass

 void scamper_http_free(scamper_http_t *http)

 scamper_list_t *scamper_http_list_get(const scamper_http_t *http)
 scamper_cycle_t *scamper_http_cycle_get(const scamper_http_t *http)
 uint32_t scamper_http_userid_get(const scamper_http_t *http)
 scamper_addr_t *scamper_http_src_get(const scamper_http_t *http)
 scamper_addr_t *scamper_http_dst_get(const scamper_http_t *http)
 uint16_t scamper_http_sport_get(const scamper_http_t *http)
 uint16_t scamper_http_dport_get(const scamper_http_t *http)
 const timeval *scamper_http_start_get(const scamper_http_t *http)
 uint8_t scamper_http_stop_get(const scamper_http_t *http)
 char *scamper_http_stop_tostr(const scamper_http_t *http, char *buf, size_t len)
 uint8_t scamper_http_type_get(const scamper_http_t *http)
 char *scamper_http_type_tostr(const scamper_http_t *http, char *buf, size_t len)
 const char *scamper_http_host_get(const scamper_http_t *http)
 const char *scamper_http_file_get(const scamper_http_t *http)

 uint32_t scamper_http_bufc_get(const scamper_http_t *http)
 scamper_http_buf_t *scamper_http_buf_get(const scamper_http_t *http, uint32_t i)
 void scamper_http_buf_free(scamper_http_buf_t *htb)
 scamper_http_buf_t *scamper_http_buf_use(scamper_http_buf_t *htb)
 const timeval *scamper_http_buf_tv_get(const scamper_http_buf_t *htb)
 const uint8_t *scamper_http_buf_data_get(const scamper_http_buf_t *htb)
 uint16_t scamper_http_buf_len_get(const scamper_http_buf_t *htb)
 bint scamper_http_buf_is_tx(const scamper_http_buf_t *htb)
 bint scamper_http_buf_is_rx(const scamper_http_buf_t *htb)
 bint scamper_http_buf_is_tls(const scamper_http_buf_t *htb)
 bint scamper_http_buf_is_hdr(const scamper_http_buf_t *htb)
 bint scamper_http_buf_is_data(const scamper_http_buf_t *htb)
 char *scamper_http_buf_dir_tostr(const scamper_http_buf_t *htb, char *buf, size_t len)
 char *scamper_http_buf_type_tostr(const scamper_http_buf_t *htb, char *buf, size_t len)

 int scamper_http_status_code_get(const scamper_http_t *http, uint16_t *status)
 int scamper_http_url_len_get(const scamper_http_t *http, size_t *len)
 int scamper_http_url_get(const scamper_http_t *http, char *buf, size_t len)
 int scamper_http_rx_hdr_len_get(const scamper_http_t *http, size_t *len)
 int scamper_http_rx_hdr_get(const scamper_http_t *http, uint8_t *buf, size_t len)
 int scamper_http_rx_data_len_get(const scamper_http_t *http, size_t *len)
 int scamper_http_rx_data_get(const scamper_http_t *http, uint8_t *buf, size_t len)
 int scamper_http_tx_hdr_len_get(const scamper_http_t *http, size_t *len)
 int scamper_http_tx_hdr_get(const scamper_http_t *http, uint8_t *buf, size_t len)

 int scamper_http_tx_hdr_name_get(const scamper_http_t *http, const char *name, char **value)
 int scamper_http_rx_hdr_name_get(const scamper_http_t *http, const char *name, char **value)

 scamper_http_hdr_fields_t *scamper_http_rx_hdr_fields_get(const scamper_http_t *http)
 scamper_http_hdr_fields_t *scamper_http_tx_hdr_fields_get(const scamper_http_t *http)

 void scamper_http_hdr_fields_free(scamper_http_hdr_fields_t *htfs)
 size_t scamper_http_hdr_fields_count_get(const scamper_http_hdr_fields_t *htfs)
 scamper_http_hdr_field_t *scamper_http_hdr_fields_get(const scamper_http_hdr_fields_t *htfs, size_t x)
 const char *scamper_http_hdr_field_name_get(const scamper_http_hdr_field_t *htf)
 const char *scamper_http_hdr_field_value_get(const scamper_http_hdr_field_t *htf)



# scamper python interface - cython interface to scamper_sniff_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2024 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_sniff.h":
 ctypedef struct scamper_sniff_t:
  pass
 ctypedef struct scamper_sniff_pkt_t:
  pass

 void scamper_sniff_free(scamper_sniff_t *sniff)

 scamper_list_t *scamper_sniff_list_get(const scamper_sniff_t *sniff)
 scamper_cycle_t *scamper_sniff_cycle_get(const scamper_sniff_t *sniff)
 uint32_t scamper_sniff_userid_get(const scamper_sniff_t *sniff)
 const timeval *scamper_sniff_start_get(const scamper_sniff_t *sniff)
 const timeval *scamper_sniff_finish_get(const scamper_sniff_t *sniff)
 uint8_t scamper_sniff_stop_reason_get(const scamper_sniff_t *sniff)
 uint32_t scamper_sniff_limit_pktc_get(const scamper_sniff_t *sniff)
 const timeval *scamper_sniff_limit_time_get(const scamper_sniff_t *sniff)
 scamper_addr_t *scamper_sniff_src_get(const scamper_sniff_t *sniff)
 uint16_t scamper_sniff_icmpid_get(const scamper_sniff_t *sniff)
 scamper_sniff_pkt_t *scamper_sniff_pkt_get(const scamper_sniff_t *sniff, uint32_t i)
 uint32_t scamper_sniff_pktc_get(const scamper_sniff_t *sniff)

 scamper_sniff_pkt_t *scamper_sniff_pkt_use(scamper_sniff_pkt_t *pkt)
 void scamper_sniff_pkt_free(scamper_sniff_pkt_t *pkt)
 const timeval *scamper_sniff_pkt_tv_get(const scamper_sniff_pkt_t *pkt)
 const uint8_t *scamper_sniff_pkt_data_get(const scamper_sniff_pkt_t *pkt)
 uint16_t scamper_sniff_pkt_len_get(const scamper_sniff_pkt_t *pkt)



# scamper python interface - cython interface to scamper_dealias_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2024 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_dealias.h":
 ctypedef struct scamper_dealias_t:
  pass
 ctypedef struct scamper_dealias_mercator_t:
  pass
 ctypedef struct scamper_dealias_ally_t:
  pass
 ctypedef struct scamper_dealias_radargun_t:
  pass
 ctypedef struct scamper_dealias_prefixscan_t:
  pass
 ctypedef struct scamper_dealias_bump_t:
  pass
 ctypedef struct scamper_dealias_midarest_t:
  pass
 ctypedef struct scamper_dealias_midardisc_t:
  pass
 ctypedef struct scamper_dealias_midardisc_round_t:
  pass
 ctypedef struct scamper_dealias_probe_t:
  pass
 ctypedef struct scamper_dealias_probedef_udp_t:
  pass
 ctypedef struct scamper_dealias_probedef_icmp_t:
  pass
 ctypedef struct scamper_dealias_probedef_tcp_t:
  pass
 ctypedef struct scamper_dealias_probedef_t:
  pass
 ctypedef struct scamper_dealias_reply_t:
  pass

 char *scamper_dealias_tojson(const scamper_dealias_t *dealias, size_t *l)
 char *scamper_dealias_totext(const scamper_dealias_t *dealias, size_t *l)

 void scamper_dealias_free(scamper_dealias_t *dealias)

 scamper_list_t *scamper_dealias_list_get(const scamper_dealias_t *dealias)
 scamper_cycle_t *scamper_dealias_cycle_get(const scamper_dealias_t *dealias)
 uint32_t scamper_dealias_userid_get(const scamper_dealias_t *dealias)
 const timeval *scamper_dealias_start_get(const scamper_dealias_t *dealias)
 scamper_dealias_ally_t *scamper_dealias_ally_get(const scamper_dealias_t *dealias)
 scamper_dealias_mercator_t *scamper_dealias_mercator_get(const scamper_dealias_t *dealias)
 scamper_dealias_radargun_t *scamper_dealias_radargun_get(const scamper_dealias_t *dealias)
 scamper_dealias_prefixscan_t *scamper_dealias_prefixscan_get(const scamper_dealias_t *dealias)
 scamper_dealias_bump_t *scamper_dealias_bump_get(const scamper_dealias_t *dealias)
 scamper_dealias_midarest_t *scamper_dealias_midarest_get(const scamper_dealias_t *dealias)
 scamper_dealias_midardisc_t *scamper_dealias_midardisc_get(const scamper_dealias_t *dealias)
 scamper_dealias_probe_t *scamper_dealias_probe_get(const scamper_dealias_t *dealias, uint32_t i)
 uint32_t scamper_dealias_probec_get(const scamper_dealias_t *dealias)

 bint scamper_dealias_method_is_mercator(const scamper_dealias_t *dealias)
 bint scamper_dealias_method_is_ally(const scamper_dealias_t *dealias)
 bint scamper_dealias_method_is_radargun(const scamper_dealias_t *dealias)
 bint scamper_dealias_method_is_prefixscan(const scamper_dealias_t *dealias)
 bint scamper_dealias_method_is_bump(const scamper_dealias_t *dealias)
 bint scamper_dealias_method_is_midarest(const scamper_dealias_t *dealias)
 bint scamper_dealias_method_is_midardisc(const scamper_dealias_t *dealias)

 uint8_t scamper_dealias_result_get(const scamper_dealias_t *dealias)
 bint scamper_dealias_result_is_aliases(const scamper_dealias_t *dealias)

 scamper_dealias_probedef_t *scamper_dealias_mercator_def_get(const scamper_dealias_mercator_t *mc)
 uint8_t scamper_dealias_mercator_attempts_get(const scamper_dealias_mercator_t *mc)
 const timeval *scamper_dealias_mercator_wait_timeout_get(const scamper_dealias_mercator_t *mc)

 scamper_dealias_probedef_t *scamper_dealias_ally_def0_get(const scamper_dealias_ally_t *ally)
 scamper_dealias_probedef_t *scamper_dealias_ally_def1_get(const scamper_dealias_ally_t *ally)
 const timeval *scamper_dealias_ally_wait_probe_get(const scamper_dealias_ally_t *ally)
 const timeval *scamper_dealias_ally_wait_timeout_get(const scamper_dealias_ally_t *ally)
 uint8_t scamper_dealias_ally_attempts_get(const scamper_dealias_ally_t *ally)
 uint8_t scamper_dealias_ally_flags_get(const scamper_dealias_ally_t *ally)
 uint16_t scamper_dealias_ally_fudge_get(const scamper_dealias_ally_t *ally)
 bint scamper_dealias_ally_is_nobs(const scamper_dealias_ally_t *ally)

 scamper_dealias_probedef_t *scamper_dealias_radargun_def_get(const scamper_dealias_radargun_t *rg, uint32_t i)
 uint32_t scamper_dealias_radargun_defc_get(const scamper_dealias_radargun_t *rg)
 uint16_t scamper_dealias_radargun_rounds_get(const scamper_dealias_radargun_t *rg)
 const timeval *scamper_dealias_radargun_wait_probe_get(const scamper_dealias_radargun_t *rg)
 const timeval *scamper_dealias_radargun_wait_round_get(const scamper_dealias_radargun_t *rg)
 const timeval *scamper_dealias_radargun_wait_timeout_get(const scamper_dealias_radargun_t *rg)
 uint8_t scamper_dealias_radargun_flags_get(const scamper_dealias_radargun_t *rg)

 scamper_addr_t *scamper_dealias_prefixscan_a_get(const scamper_dealias_prefixscan_t *pf)
 scamper_addr_t *scamper_dealias_prefixscan_b_get(const scamper_dealias_prefixscan_t *pf)
 scamper_addr_t *scamper_dealias_prefixscan_ab_get(const scamper_dealias_prefixscan_t *pf)
 scamper_addr_t *scamper_dealias_prefixscan_xs_get(const scamper_dealias_prefixscan_t *pf, uint16_t i)
 uint16_t scamper_dealias_prefixscan_xc_get(const scamper_dealias_prefixscan_t *pf)
 uint8_t scamper_dealias_prefixscan_prefix_get(const scamper_dealias_prefixscan_t *pf)
 uint8_t scamper_dealias_prefixscan_attempts_get(const scamper_dealias_prefixscan_t *pf)
 uint8_t scamper_dealias_prefixscan_replyc_get(const scamper_dealias_prefixscan_t *pf)
 uint16_t scamper_dealias_prefixscan_fudge_get(const scamper_dealias_prefixscan_t *pf)
 const timeval *scamper_dealias_prefixscan_wait_probe_get(const scamper_dealias_prefixscan_t *pf)
 const timeval *scamper_dealias_prefixscan_wait_timeout_get(const scamper_dealias_prefixscan_t *pf)
 uint8_t scamper_dealias_prefixscan_flags_get(const scamper_dealias_prefixscan_t *pf)
 scamper_dealias_probedef_t *scamper_dealias_prefixscan_def_get(const scamper_dealias_prefixscan_t *pf, uint16_t i)
 uint16_t scamper_dealias_prefixscan_defc_get(const scamper_dealias_prefixscan_t *pf)
 bint scamper_dealias_prefixscan_is_csa(const scamper_dealias_prefixscan_t *pfs)
 bint scamper_dealias_prefixscan_is_nobs(const scamper_dealias_prefixscan_t *pfs)

 scamper_dealias_probedef_t *scamper_dealias_bump_def0_get(const scamper_dealias_bump_t *bump)
 scamper_dealias_probedef_t *scamper_dealias_bump_def1_get(const scamper_dealias_bump_t *bump)
 const timeval *scamper_dealias_bump_wait_probe_get(const scamper_dealias_bump_t *bump)
 const timeval *scamper_dealias_bump_limit_get(const scamper_dealias_bump_t *bump)
 uint8_t scamper_dealias_bump_attempts_get(const scamper_dealias_bump_t *bump)

 scamper_dealias_probedef_t *scamper_dealias_midarest_def_get(const scamper_dealias_midarest_t *me, uint16_t i)
 uint16_t scamper_dealias_midarest_defc_get(const scamper_dealias_midarest_t *me)
 uint8_t scamper_dealias_midarest_rounds_get(const scamper_dealias_midarest_t *me)
 const timeval *scamper_dealias_midarest_wait_probe_get(const scamper_dealias_midarest_t *me)
 const timeval *scamper_dealias_midarest_wait_round_get(const scamper_dealias_midarest_t *me)
 const timeval *scamper_dealias_midarest_wait_timeout_get(const scamper_dealias_midarest_t *me)

 scamper_dealias_probedef_t *scamper_dealias_midardisc_def_get(const scamper_dealias_midardisc_t *md, uint32_t i)
 uint32_t scamper_dealias_midardisc_defc_get(const scamper_dealias_midardisc_t *md)
 const timeval *scamper_dealias_midardisc_wait_timeout_get(const scamper_dealias_midardisc_t *md)
 const timeval *scamper_dealias_midardisc_startat_get(const scamper_dealias_midardisc_t *md)

 scamper_dealias_midardisc_round_t *scamper_dealias_midardisc_round_alloc()
 void scamper_dealias_midardisc_round_free(scamper_dealias_midardisc_round_t *r)
 void scamper_dealias_midardisc_round_begin_set(scamper_dealias_midardisc_round_t *r, uint32_t begin)
 void scamper_dealias_midardisc_round_end_set(scamper_dealias_midardisc_round_t *r, uint32_t end)
 void scamper_dealias_midardisc_round_start_set(scamper_dealias_midardisc_round_t *r, const timeval *start)
 uint32_t scamper_dealias_midardisc_round_begin_get(const scamper_dealias_midardisc_round_t *r)
 uint32_t scamper_dealias_midardisc_round_end_get(const scamper_dealias_midardisc_round_t *r)
 const timeval *scamper_dealias_midardisc_round_start_get(const scamper_dealias_midardisc_round_t *r)

 scamper_dealias_probedef_t *scamper_dealias_probe_def_get(const scamper_dealias_probe_t *probe)
 uint32_t scamper_dealias_probe_seq_get(const scamper_dealias_probe_t *probe)
 const timeval *scamper_dealias_probe_tx_get(const scamper_dealias_probe_t *probe)
 scamper_dealias_reply_t *scamper_dealias_probe_reply_get(const scamper_dealias_probe_t *probe, uint16_t i)
 uint16_t scamper_dealias_probe_replyc_get(const scamper_dealias_probe_t *probe)
 uint16_t scamper_dealias_probe_ipid_get(const scamper_dealias_probe_t *probe)

 scamper_addr_t *scamper_dealias_probedef_src_get(const scamper_dealias_probedef_t *pd)
 scamper_addr_t *scamper_dealias_probedef_dst_get(const scamper_dealias_probedef_t *pd)
 uint32_t scamper_dealias_probedef_id_get(const scamper_dealias_probedef_t *pd)
 uint8_t scamper_dealias_probedef_method_get(const scamper_dealias_probedef_t *pd)
 char *scamper_dealias_probedef_method_tostr(const scamper_dealias_probedef_t *pd, char *buf, size_t l)
 int scamper_dealias_probedef_method_fromstr(const char *buf, uint8_t *meth)
 bint scamper_dealias_probedef_is_udp(const scamper_dealias_probedef_t *pd)
 bint scamper_dealias_probedef_is_icmp(const scamper_dealias_probedef_t *pd)
 bint scamper_dealias_probedef_is_tcp(const scamper_dealias_probedef_t *pd)
 uint8_t scamper_dealias_probedef_ttl_get(const scamper_dealias_probedef_t *pd)
 uint8_t scamper_dealias_probedef_tos_get(const scamper_dealias_probedef_t *pd)
 uint16_t scamper_dealias_probedef_size_get(const scamper_dealias_probedef_t *pd)
 uint16_t scamper_dealias_probedef_mtu_get(const scamper_dealias_probedef_t *pd)
 scamper_dealias_probedef_udp_t *scamper_dealias_probedef_udp_get(const scamper_dealias_probedef_t *pd)
 scamper_dealias_probedef_tcp_t *scamper_dealias_probedef_tcp_get(const scamper_dealias_probedef_t *pd)
 scamper_dealias_probedef_icmp_t *scamper_dealias_probedef_icmp_get(const scamper_dealias_probedef_t *pd)
 uint16_t scamper_dealias_probedef_udp_sport_get(const scamper_dealias_probedef_udp_t *udp)
 uint16_t scamper_dealias_probedef_udp_dport_get(const scamper_dealias_probedef_udp_t *udp)
 uint16_t scamper_dealias_probedef_icmp_csum_get(const scamper_dealias_probedef_icmp_t *icmp)
 uint16_t scamper_dealias_probedef_icmp_id_get(const scamper_dealias_probedef_icmp_t *icmp)
 uint16_t scamper_dealias_probedef_tcp_sport_get(const scamper_dealias_probedef_tcp_t *tcp)
 uint16_t scamper_dealias_probedef_tcp_dport_get(const scamper_dealias_probedef_tcp_t *tcp)
 uint8_t scamper_dealias_probedef_tcp_flags_get(const scamper_dealias_probedef_tcp_t *tcp)

 scamper_dealias_probedef_t *scamper_dealias_probedef_alloc()
 int scamper_dealias_probedef_method_set(scamper_dealias_probedef_t *pd, const char *meth)
 int scamper_dealias_probedef_src_set(scamper_dealias_probedef_t *pd, scamper_addr_t *src)
 int scamper_dealias_probedef_dst_set(scamper_dealias_probedef_t *pd, scamper_addr_t *dst)
 void scamper_dealias_probedef_ttl_set(scamper_dealias_probedef_t *pd, uint8_t ttl)
 void scamper_dealias_probedef_tos_set(scamper_dealias_probedef_t *pd, uint8_t tos)
 void scamper_dealias_probedef_size_set(scamper_dealias_probedef_t *pd, uint16_t size)
 void scamper_dealias_probedef_mtu_set(scamper_dealias_probedef_t *pd, uint16_t mtu)
 void scamper_dealias_probedef_icmp_csum_set(scamper_dealias_probedef_icmp_t *icmp, uint16_t cs)
 void scamper_dealias_probedef_icmp_id_set(scamper_dealias_probedef_icmp_t *icmp, uint16_t icmp_id)
 void scamper_dealias_probedef_udp_sport_set(scamper_dealias_probedef_udp_t *udp, uint16_t sp)
 void scamper_dealias_probedef_udp_dport_set(scamper_dealias_probedef_udp_t *udp, uint16_t dp)
 void scamper_dealias_probedef_tcp_sport_set(scamper_dealias_probedef_tcp_t *tcp, uint16_t sp)
 void scamper_dealias_probedef_tcp_dport_set(scamper_dealias_probedef_tcp_t *tcp, uint16_t dp)

 scamper_addr_t *scamper_dealias_reply_src_get(const scamper_dealias_reply_t *reply)
 const timeval *scamper_dealias_reply_rx_get(const scamper_dealias_reply_t *reply)
 uint8_t scamper_dealias_reply_flags_get(const scamper_dealias_reply_t *reply)
 uint8_t scamper_dealias_reply_proto_get(const scamper_dealias_reply_t *reply)
 uint8_t scamper_dealias_reply_ttl_get(const scamper_dealias_reply_t *reply)
 uint16_t scamper_dealias_reply_size_get(const scamper_dealias_reply_t *reply)
 uint8_t scamper_dealias_reply_icmp_type_get(const scamper_dealias_reply_t *reply)
 uint8_t scamper_dealias_reply_icmp_code_get(const scamper_dealias_reply_t *reply)
 uint8_t scamper_dealias_reply_icmp_q_ttl_get(const scamper_dealias_reply_t *reply)
 uint8_t scamper_dealias_reply_tcp_flags_get(const scamper_dealias_reply_t *reply)
 uint16_t scamper_dealias_reply_ipid_get(const scamper_dealias_reply_t *reply)
 uint32_t scamper_dealias_reply_ipid32_get(const scamper_dealias_reply_t *reply)
 bint scamper_dealias_reply_is_ipid32(const scamper_dealias_reply_t *reply)
 bint scamper_dealias_reply_is_icmp(const scamper_dealias_reply_t *reply)
 bint scamper_dealias_reply_is_icmp_q(const scamper_dealias_reply_t *reply)
 bint scamper_dealias_reply_is_icmp_unreach(const scamper_dealias_reply_t *reply)
 bint scamper_dealias_reply_is_icmp_unreach_port(const scamper_dealias_reply_t *reply)
 bint scamper_dealias_reply_is_icmp_ttl_exp(const scamper_dealias_reply_t *reply)
 bint scamper_dealias_reply_is_tcp(const scamper_dealias_reply_t *reply)
 bint scamper_dealias_reply_from_target(const scamper_dealias_probe_t *probe,
				        const scamper_dealias_reply_t *reply)

 scamper_dealias_probe_t *scamper_dealias_probe_use(scamper_dealias_probe_t *probe)
 void scamper_dealias_probe_free(scamper_dealias_probe_t *probe)
 scamper_dealias_probedef_t *scamper_dealias_probedef_use(scamper_dealias_probedef_t *pd)
 void scamper_dealias_probedef_free(scamper_dealias_probedef_t *pd)
 scamper_dealias_reply_t *scamper_dealias_reply_use(scamper_dealias_reply_t *reply)
 void scamper_dealias_reply_free(scamper_dealias_reply_t *reply)
 scamper_dealias_mercator_t *scamper_dealias_mercator_use(scamper_dealias_mercator_t *mc)
 void scamper_dealias_mercator_free(scamper_dealias_mercator_t *mc)
 scamper_dealias_ally_t *scamper_dealias_ally_use(scamper_dealias_ally_t *ally)
 void scamper_dealias_ally_free(scamper_dealias_ally_t *ally)
 scamper_dealias_radargun_t *scamper_dealias_radargun_use(scamper_dealias_radargun_t *rg)
 void scamper_dealias_radargun_free(scamper_dealias_radargun_t *rg)
 scamper_dealias_prefixscan_t *scamper_dealias_prefixscan_use(scamper_dealias_prefixscan_t *pf)
 void scamper_dealias_prefixscan_free(scamper_dealias_prefixscan_t *pf)



# scamper python interface - cython interface to scamper_host_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2025 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_host.h":
 ctypedef struct scamper_host_t:
  pass
 ctypedef struct scamper_host_rr_t:
  pass
 ctypedef struct scamper_host_query_t:
  pass
 ctypedef struct scamper_host_rr_soa_t:
  pass
 ctypedef struct scamper_host_rr_mx_t:
  pass
 ctypedef struct scamper_host_rr_txt_t:
  pass
 ctypedef struct scamper_host_rr_opt_t:
  pass
 ctypedef struct scamper_host_rr_opt_elem_t:
  pass
 ctypedef struct scamper_host_rr_svcb_t:
  pass
 ctypedef struct scamper_host_rr_svcb_param_t:
  pass

 char *scamper_host_tojson(const scamper_host_t *host, size_t *l)

 void scamper_host_free(scamper_host_t *host)

 char *scamper_host_stop_tostr(const scamper_host_t *h, char *b, size_t l)
 char *scamper_host_qtype_tostr(uint16_t qtype, char *b, size_t l)
 char *scamper_host_qclass_tostr(uint16_t qclass, char *b, size_t l)
 char *scamper_host_rcode_tostr(uint8_t rcode, char *b, size_t l)

 scamper_list_t *scamper_host_list_get(const scamper_host_t *host)
 scamper_cycle_t *scamper_host_cycle_get(const scamper_host_t *host)
 scamper_addr_t *scamper_host_src_get(const scamper_host_t *host)
 scamper_addr_t *scamper_host_dst_get(const scamper_host_t *host)
 uint32_t scamper_host_userid_get(const scamper_host_t *host)
 const timeval *scamper_host_start_get(const scamper_host_t *host)
 uint16_t scamper_host_flags_get(const scamper_host_t *host)
 uint16_t scamper_host_wait_get(const scamper_host_t *host)
 uint8_t scamper_host_stop_get(const scamper_host_t *host)
 uint8_t scamper_host_retries_get(const scamper_host_t *host)
 uint16_t scamper_host_qtype_get(const scamper_host_t *host)
 uint16_t scamper_host_qclass_get(const scamper_host_t *host)
 const char *scamper_host_qname_get(const scamper_host_t *host)
 uint8_t scamper_host_qcount_get(const scamper_host_t *host)
 const char *scamper_host_ecs_get(const scamper_host_t *host)

 scamper_host_query_t *scamper_host_query_get(const scamper_host_t *host, uint8_t i)
 scamper_host_query_t *scamper_host_query_use(scamper_host_query_t *q)
 void scamper_host_query_free(scamper_host_query_t *q)
 const timeval *scamper_host_query_tx_get(const scamper_host_query_t *q)
 const timeval *scamper_host_query_rx_get(const scamper_host_query_t *q)
 uint8_t scamper_host_query_rcode_get(const scamper_host_query_t *q)
 uint8_t scamper_host_query_flags_get(const scamper_host_query_t *q)
 uint16_t scamper_host_query_id_get(const scamper_host_query_t *q)
 uint16_t scamper_host_query_ancount_get(const scamper_host_query_t *q)
 uint16_t scamper_host_query_nscount_get(const scamper_host_query_t *q)
 uint16_t scamper_host_query_arcount_get(const scamper_host_query_t *q)
 scamper_host_rr_t *scamper_host_query_an_get(const scamper_host_query_t *q, uint16_t i)
 scamper_host_rr_t *scamper_host_query_ns_get(const scamper_host_query_t *q, uint16_t i)
 scamper_host_rr_t *scamper_host_query_ar_get(const scamper_host_query_t *q, uint16_t i)
 scamper_host_rr_t *scamper_host_query_ar_opt_get(const scamper_host_query_t *q)

 scamper_host_rr_t *scamper_host_rr_use(scamper_host_rr_t *rr)
 void scamper_host_rr_free(scamper_host_rr_t *rr)
 int scamper_host_rr_data_type(uint16_t class_n, uint16_t type_n)
 const char *scamper_host_rr_data_str_typestr(uint16_t qclass, uint16_t qtype)
 uint16_t scamper_host_rr_class_get(const scamper_host_rr_t *rr)
 uint16_t scamper_host_rr_type_get(const scamper_host_rr_t *rr)
 const char *scamper_host_rr_name_get(const scamper_host_rr_t *rr)
 uint32_t scamper_host_rr_ttl_get(const scamper_host_rr_t *rr)
 const void *scamper_host_rr_v_get(const scamper_host_rr_t *rr)
 scamper_addr_t *scamper_host_rr_addr_get(const scamper_host_rr_t *rr)
 const char *scamper_host_rr_str_get(const scamper_host_rr_t *rr)
 scamper_host_rr_soa_t *scamper_host_rr_soa_get(const scamper_host_rr_t *rr)
 scamper_host_rr_mx_t *scamper_host_rr_mx_get(const scamper_host_rr_t *rr)
 scamper_host_rr_txt_t *scamper_host_rr_txt_get(const scamper_host_rr_t *rr)
 scamper_host_rr_opt_t *scamper_host_rr_opt_get(const scamper_host_rr_t *rr)
 scamper_host_rr_svcb_t *scamper_host_rr_svcb_get(const scamper_host_rr_t *rr)

 scamper_host_rr_mx_t *scamper_host_rr_mx_use(scamper_host_rr_mx_t *mx)
 void scamper_host_rr_mx_free(scamper_host_rr_mx_t *mx)
 uint16_t scamper_host_rr_mx_preference_get(const scamper_host_rr_mx_t *mx)
 const char *scamper_host_rr_mx_exchange_get(const scamper_host_rr_mx_t *mx)

 scamper_host_rr_soa_t *scamper_host_rr_soa_use(scamper_host_rr_soa_t *soa)
 void scamper_host_rr_soa_free(scamper_host_rr_soa_t *soa)
 const char *scamper_host_rr_soa_mname_get(const scamper_host_rr_soa_t *soa)
 const char *scamper_host_rr_soa_rname_get(const scamper_host_rr_soa_t *soa)
 uint32_t scamper_host_rr_soa_serial_get(const scamper_host_rr_soa_t *soa)
 uint32_t scamper_host_rr_soa_refresh_get(const scamper_host_rr_soa_t *soa)
 uint32_t scamper_host_rr_soa_retry_get(const scamper_host_rr_soa_t *soa)
 uint32_t scamper_host_rr_soa_expire_get(const scamper_host_rr_soa_t *soa)
 uint32_t scamper_host_rr_soa_minimum_get(const scamper_host_rr_soa_t *soa)

 scamper_host_rr_txt_t *scamper_host_rr_txt_use(scamper_host_rr_txt_t *txt)
 void scamper_host_rr_txt_free(scamper_host_rr_txt_t *txt)
 uint16_t scamper_host_rr_txt_strc_get(const scamper_host_rr_txt_t *txt)
 const char *scamper_host_rr_txt_str_get(const scamper_host_rr_txt_t *txt, uint16_t i)

 scamper_host_rr_opt_t *scamper_host_rr_opt_use(scamper_host_rr_opt_t *opt)
 void scamper_host_rr_opt_free(scamper_host_rr_opt_t *opt)
 uint16_t scamper_host_rr_opt_elemc_get(const scamper_host_rr_opt_t *opt)
 void scamper_host_rr_opt_elem_free(scamper_host_rr_opt_elem_t *elem)
 scamper_host_rr_opt_elem_t *scamper_host_rr_opt_elem_get(const scamper_host_rr_opt_t *opt, uint16_t i)
 scamper_host_rr_opt_elem_t *scamper_host_rr_opt_elem_use(scamper_host_rr_opt_elem_t *elem)
 uint16_t scamper_host_rr_opt_elem_code_get(const scamper_host_rr_opt_elem_t *elem)
 char *scamper_host_rr_opt_elem_code_tostr(uint16_t code, char *b, size_t l)
 uint16_t scamper_host_rr_opt_elem_len_get(const scamper_host_rr_opt_elem_t *elem)
 const uint8_t *scamper_host_rr_opt_elem_data_get(const scamper_host_rr_opt_elem_t *elem)

 scamper_host_rr_svcb_t *scamper_host_rr_svcb_use(scamper_host_rr_svcb_t *svcb)
 void scamper_host_rr_svcb_free(scamper_host_rr_svcb_t *svcb)
 const char *scamper_host_rr_svcb_target_get(const scamper_host_rr_svcb_t *svcb)
 uint16_t scamper_host_rr_svcb_priority_get(const scamper_host_rr_svcb_t *svcb)
 uint16_t scamper_host_rr_svcb_paramc_get(const scamper_host_rr_svcb_t *svcb)
 void scamper_host_rr_svcb_param_free(scamper_host_rr_svcb_param_t *param)
 scamper_host_rr_svcb_param_t *scamper_host_rr_svcb_param_get(const scamper_host_rr_svcb_t *svcb, uint16_t i)
 scamper_host_rr_svcb_param_t *scamper_host_rr_svcb_param_use(scamper_host_rr_svcb_param_t *param)
 uint16_t scamper_host_rr_svcb_param_key_get(const scamper_host_rr_svcb_param_t *param)
 char *scamper_host_rr_svcb_param_key_tostr(uint16_t code, char *b, size_t l)
 uint16_t scamper_host_rr_svcb_param_len_get(const scamper_host_rr_svcb_param_t *param)
 const uint8_t *scamper_host_rr_svcb_param_val_get(const scamper_host_rr_svcb_param_t *param)



# scamper python interface - cython interface to scamper_udpprobe_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2024 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_udpprobe.h":
 ctypedef struct scamper_udpprobe_t:
  pass
 ctypedef struct scamper_udpprobe_probe_t:
  pass
 ctypedef struct scamper_udpprobe_reply_t:
  pass

 char *scamper_udpprobe_tojson(const scamper_udpprobe_t *up, size_t *l)

 void scamper_udpprobe_free(scamper_udpprobe_t *up)

 scamper_list_t *scamper_udpprobe_list_get(const scamper_udpprobe_t *up)
 scamper_cycle_t *scamper_udpprobe_cycle_get(const scamper_udpprobe_t *up)
 uint32_t scamper_udpprobe_userid_get(const scamper_udpprobe_t *up)
 scamper_addr_t *scamper_udpprobe_src_get(const scamper_udpprobe_t *up)
 scamper_addr_t *scamper_udpprobe_dst_get(const scamper_udpprobe_t *up)
 uint16_t scamper_udpprobe_sport_get(const scamper_udpprobe_t *up)
 uint16_t scamper_udpprobe_dport_get(const scamper_udpprobe_t *up)
 const timeval *scamper_udpprobe_start_get(const scamper_udpprobe_t *up)
 const timeval *scamper_udpprobe_wait_timeout_get(const scamper_udpprobe_t *up)
 const timeval *scamper_udpprobe_wait_probe_get(const scamper_udpprobe_t *up)
 int scamper_udpprobe_flag_is_exitfirst(const scamper_udpprobe_t *up)
 const uint8_t *scamper_udpprobe_data_get(const scamper_udpprobe_t *up)
 uint16_t scamper_udpprobe_len_get(const scamper_udpprobe_t *up)
 uint8_t scamper_udpprobe_probe_count_get(const scamper_udpprobe_t *up);
 uint8_t scamper_udpprobe_probe_sent_get(const scamper_udpprobe_t *up);
 uint8_t scamper_udpprobe_stop_count_get(const scamper_udpprobe_t *up);
 scamper_udpprobe_probe_t *scamper_udpprobe_probe_get(const scamper_udpprobe_t *up, uint8_t i);

 void scamper_udpprobe_probe_free(scamper_udpprobe_probe_t *probe);
 scamper_udpprobe_probe_t *scamper_udpprobe_probe_use(scamper_udpprobe_probe_t *probe);
 const timeval *scamper_udpprobe_probe_tx_get(const scamper_udpprobe_probe_t *probe);
 uint16_t scamper_udpprobe_probe_sport_get(const scamper_udpprobe_probe_t *probe);
 scamper_udpprobe_reply_t *scamper_udpprobe_probe_reply_get(const scamper_udpprobe_probe_t *probe, uint8_t i);
 uint8_t scamper_udpprobe_probe_replyc_get(const scamper_udpprobe_probe_t *probe);

 void scamper_udpprobe_reply_free(scamper_udpprobe_reply_t *ur)
 scamper_udpprobe_reply_t *scamper_udpprobe_reply_use(scamper_udpprobe_reply_t *ur)
 const uint8_t *scamper_udpprobe_reply_data_get(const scamper_udpprobe_reply_t *ur)
 uint16_t scamper_udpprobe_reply_len_get(const scamper_udpprobe_reply_t *ur)
 const timeval *scamper_udpprobe_reply_rx_get(const scamper_udpprobe_reply_t *ur)
 const char *scamper_udpprobe_reply_ifname_get(const scamper_udpprobe_reply_t *ur)



# scamper python interface - cython interface to scamper_tbit_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2024 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t
from posix.time cimport timeval

cdef extern from "scamper_addr.h":
 ctypedef struct scamper_addr_t:
  pass

cdef extern from "scamper_list.h":
 ctypedef struct scamper_list_t:
  pass
 ctypedef struct scamper_cycle_t:
  pass

cdef extern from "scamper_tbit.h":
 ctypedef struct scamper_tbit_t:
  pass

 ctypedef struct scamper_tbit_pkt_t:
  pass

 char *scamper_tbit_tojson(const scamper_tbit_t *tbit, size_t *l)

 void scamper_tbit_free(scamper_tbit_t *tbit)
 scamper_list_t *scamper_tbit_list_get(const scamper_tbit_t *tbit)
 scamper_cycle_t *scamper_tbit_cycle_get(const scamper_tbit_t *tbit)
 uint32_t scamper_tbit_userid_get(const scamper_tbit_t *tbit)
 scamper_addr_t *scamper_tbit_src_get(const scamper_tbit_t *tbit)
 scamper_addr_t *scamper_tbit_dst_get(const scamper_tbit_t *tbit)
 uint16_t scamper_tbit_sport_get(const scamper_tbit_t *tbit)
 uint16_t scamper_tbit_dport_get(const scamper_tbit_t *tbit)
 const timeval *scamper_tbit_start_get(const scamper_tbit_t *tbit)
 char *scamper_tbit_result_tostr(const scamper_tbit_t *tbit,char *buf,size_t len)
 scamper_tbit_pkt_t *scamper_tbit_pkt_get(const scamper_tbit_t *tbit,uint32_t i)
 uint32_t scamper_tbit_pktc_get(const scamper_tbit_t *tbit)
 uint8_t scamper_tbit_type_get(const scamper_tbit_t *tbit)
 uint8_t scamper_tbit_app_proto_get(const scamper_tbit_t *tbit)
 uint32_t scamper_tbit_options_get(const scamper_tbit_t *tbit)
 uint16_t scamper_tbit_client_mss_get(const scamper_tbit_t *tbit)
 const uint8_t *scamper_tbit_client_fo_cookie_get(const scamper_tbit_t *tbit)
 uint8_t scamper_tbit_client_fo_cookielen_get(const scamper_tbit_t *tbit)
 uint8_t scamper_tbit_client_wscale_get(const scamper_tbit_t *tbit)
 uint8_t scamper_tbit_client_ipttl_get(const scamper_tbit_t *tbit)
 uint8_t scamper_tbit_client_syn_retx_get(const scamper_tbit_t *tbit)
 uint8_t scamper_tbit_client_dat_retx_get(const scamper_tbit_t *tbit)
 uint16_t scamper_tbit_server_mss_get(const scamper_tbit_t *tbit)
 int scamper_tbit_server_fo_cookie_get(scamper_tbit_t *tbit,
			               uint8_t *cookie, uint8_t *cookie_len)

 scamper_tbit_pkt_t *scamper_tbit_pkt_use(scamper_tbit_pkt_t *pkt)
 void scamper_tbit_pkt_free(scamper_tbit_pkt_t *pkt)
 const timeval *scamper_tbit_pkt_tv_get(const scamper_tbit_pkt_t *pkt)
 uint8_t scamper_tbit_pkt_dir_get(const scamper_tbit_pkt_t *pkt)
 uint16_t scamper_tbit_pkt_len_get(const scamper_tbit_pkt_t *pkt)
 const uint8_t *scamper_tbit_pkt_data_get(const scamper_tbit_pkt_t *pkt)



from setuptools import Extension, setup
import textwrap

setup(
    name = "scamper",
    version = "20250630",
    description = "A module to interact with scamper processes and data",
    author = "Matthew Luckie",
    author_email = "mjl@luckie.org.nz",
    url = "https://www.caida.org/tools/measurement/scamper/",
    project_urls = {
        "Documentation": "https://www.caida.org/catalog/software/scamper/python/",
    },
    license = "GPL-2.0-only",
    ext_modules = [
        Extension("scamper", ["scamper.c"],
                  libraries=["scamperfile", "scamperctrl"]),
    ],
    keywords = ["Internet measurement", "ping", "traceroute", "dns", "http",
                "alias resolution"
    ],
    classifiers = [
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Scientific/Engineering",
    ],
    long_description_content_type = "text/x-rst",
    long_description = textwrap.dedent("""\
    scamper_ is a tool that actively probes the Internet in order to
    analyze Internet topology and performance.

    This scamper module provides convenient classes and methods for
    interacting with scamper processes and data. The scamper module
    has two related halves - classes for interacting with running
    scamper processes (through ScamperCtrl and related classes) and
    classes for reading and writing data previously collected with
    scamper (ScamperFile). These classes are supported by other
    classes that store measurement results. The types of measurements
    supported by the scamper module include ping, traceroute, alias
    resolution, DNS queries, HTTP, UDP probes, and packet capture.

    See the documentation_ for examples.

    The module requires two scamper libraries (libscamperctrl and
    libscamperfile) to run, and their development headers to build.
    These two scamper libraries are provided in the scamper source
    code distribution, and are packaged for many operating systems, as
    listed on the scamper_ website.  Where possible, use a package
    provided by your operating system before resorting to compiling
    and installing the libraries yourself.  Further, the Python module
    is already provided in packaged form by some operating systems,
    and you should use the packaged module where possible.

    .. _scamper: https://www.caida.org/tools/measurement/scamper/
    .. _documentation: https://www.caida.org/catalog/software/scamper/python/
    """)
)



# scamper python interface - cython interface to scamper_icmpext_t
#
# Author: Matthew Luckie
#
# Copyright (C) 2023-2025 The Regents of the University of California
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from libc.stdint cimport uint8_t, uint16_t, uint32_t

cdef extern from "scamper_icmpext.h":
 ctypedef struct scamper_icmpext_t:
  pass
 ctypedef struct scamper_icmpexts_t:
  pass

 scamper_icmpexts_t *scamper_icmpexts_use(scamper_icmpexts_t *exts)
 void scamper_icmpexts_free(scamper_icmpexts_t *exts)
 int scamper_icmpexts_cmp(const scamper_icmpexts_t *a, const scamper_icmpexts_t *b)
 uint16_t scamper_icmpexts_count_get(const scamper_icmpexts_t *exts)
 scamper_icmpext_t *scamper_icmpexts_ext_get(const scamper_icmpexts_t *exts, uint16_t i)

 scamper_icmpext_t *scamper_icmpext_use(scamper_icmpext_t *ie)
 void scamper_icmpext_free(scamper_icmpext_t *ie)

 int scamper_icmpext_cmp(const scamper_icmpext_t *a, const scamper_icmpext_t *b)

 bint scamper_icmpext_is_mpls(const scamper_icmpext_t *ie)
 uint16_t scamper_icmpext_mpls_count_get(const scamper_icmpext_t *ie)
 uint32_t scamper_icmpext_mpls_label_get(const scamper_icmpext_t *ie, uint16_t i)
 uint8_t scamper_icmpext_mpls_ttl_get(const scamper_icmpext_t *ie, uint16_t i)
 uint8_t scamper_icmpext_mpls_exp_get(const scamper_icmpext_t *ie, uint16_t i)
 uint8_t scamper_icmpext_mpls_s_get(const scamper_icmpext_t *ie, uint16_t i)
